@@ -3,7 +3,7 @@
  * \brief provides a map between service and shared objects
  * \see mlt_repository_s
  *
- * Copyright (C) 2003-2023 Meltytech, LLC
+ * Copyright (C) 2003-2024 Meltytech, LLC
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -339,6 +339,7 @@ void mlt_repository_close(mlt_repository self)
     mlt_properties_close(self->consumers);
     mlt_properties_close(self->filters);
     mlt_properties_close(self->producers);
+    mlt_properties_close(self->links);
     mlt_properties_close(self->transitions);
     mlt_properties_close(&self->parent);
     free(self);
@@ -465,14 +466,19 @@ mlt_properties mlt_repository_metadata(mlt_repository self,
                 metadata = callback(type, service, data);
 
                 // Cache the metadata
-                if (metadata)
+                if (metadata) {
+                    // Most links wrap a filter and references the filter's metadata
+                    mlt_destructor dtor = (type == mlt_service_link_type)
+                                              ? NULL
+                                              : (mlt_destructor) mlt_properties_close;
                     // Include dellocation and serialisation
                     mlt_properties_set_data(properties,
                                             "metadata",
                                             metadata,
                                             0,
-                                            (mlt_destructor) mlt_properties_close,
+                                            dtor,
                                             (mlt_serialiser) mlt_properties_serialise_yaml);
+                }
             }
         }
     }
@@ -567,7 +573,7 @@ static void list_presets(mlt_properties properties, const char *path, const char
                 struct stat info;
 
                 snprintf(fullname, sizeof(fullname), "%s/%s", dirname, de->d_name);
-                stat(fullname, &info);
+                mlt_stat(fullname, &info);
                 if (S_ISDIR(info.st_mode)) {
                     // recurse into subdirectories
                     char sub[PATH_MAX];
@@ -580,7 +586,7 @@ static void list_presets(mlt_properties properties, const char *path, const char
                     // load the preset
                     mlt_properties preset = mlt_properties_load(fullname);
                     if (preset && mlt_properties_count(preset)) {
-                        snprintf(fullname, 1024, "%s/%s", path, de->d_name);
+                        snprintf(fullname, sizeof(fullname), "%s/%s", path, de->d_name);
                         mlt_properties_set_data(properties,
                                                 fullname,
                                                 preset,
