@@ -1,6 +1,6 @@
 /*
  * link_timeremap.c
- * Copyright (C) 2020-2023 Meltytech, LLC
+ * Copyright (C) 2020-2024 Meltytech, LLC
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -63,9 +63,9 @@ static double integrate_source_time(mlt_link self, mlt_position position)
     mlt_position length = mlt_producer_get_length(MLT_LINK_PRODUCER(self));
     mlt_position in = mlt_producer_get_in(MLT_LINK_PRODUCER(self));
     double link_fps = mlt_producer_get_fps(MLT_LINK_PRODUCER(self));
+    mlt_position integration_distance = abs(pdata->prev_integration_position - position);
 
-    if (pdata->prev_integration_position < in
-        || (pdata->prev_integration_position > (position * 2))) {
+    if (pdata->prev_integration_position < in || integration_distance > (position - in)) {
         // Restart integration from the beginning
         pdata->prev_integration_position = in;
         pdata->prev_integration_time = 0.0;
@@ -75,15 +75,13 @@ static double integrate_source_time(mlt_link self, mlt_position position)
 
     if (pdata->prev_integration_position < position) {
         for (mlt_position p = pdata->prev_integration_position; p < position; p++) {
-            double speed
-                = mlt_properties_anim_get_double(properties, "speed_map", position - in, length);
+            double speed = mlt_properties_anim_get_double(properties, "speed_map", p - in, length);
             double time_delta = speed / link_fps;
             source_time += time_delta;
         }
     } else if (pdata->prev_integration_position > position) {
         for (mlt_position p = position; p < pdata->prev_integration_position; p++) {
-            double speed
-                = mlt_properties_anim_get_double(properties, "speed_map", position - in, length);
+            double speed = mlt_properties_anim_get_double(properties, "speed_map", p - in, length);
             double time_delta = speed / link_fps;
             source_time -= time_delta;
         }
@@ -129,6 +127,7 @@ static int link_get_audio(mlt_frame frame,
     // Validate the request
     *channels = *channels <= 0 ? 2 : *channels;
     *frequency = *frequency <= 0 ? 48000 : *frequency;
+    *format = *format == mlt_audio_none ? mlt_audio_float : *format;
 
     if (source_speed < 0.1 || source_speed > 10) {
         // Return silent samples for speeds less than 0.1 or > 10
@@ -226,6 +225,12 @@ static int link_get_audio(mlt_frame frame,
             break;
         }
 
+        if (in.format == mlt_audio_none) {
+            mlt_log_error(MLT_LINK_SERVICE(self), "Audio none: %d\n", in_frame_pos);
+            error = 1;
+            break;
+        }
+
         int samples_to_copy = in.samples - samples_to_skip;
         if (samples_to_copy > samples_needed) {
             samples_to_copy = samples_needed;
