@@ -22,8 +22,9 @@ public:
         model::Document* document,
         const std::function<void(const QString&)>& on_warning,
         ImportExport* io,
-        QSize forced_size
-    ) : SvgParserPrivate(document, on_warning, io, forced_size),
+        QSize forced_size,
+        model::FrameTime default_time
+    ) : SvgParserPrivate(document, on_warning, io, forced_size, default_time),
         resource_path(resource_path)
     {}
 
@@ -75,7 +76,7 @@ protected:
 
         if ( root.tagName() == "vector" )
         {
-            parse_vector({root, &document->main()->shapes, default_style, false});
+            parse_vector({root, &main->shapes, default_style, false});
         }
         else
         {
@@ -84,7 +85,7 @@ protected:
                 if ( auto res = get_resource(root.attribute("drawable")) )
                 {
                     if ( res->element.tagName() == "vector" )
-                        parse_vector({res->element, &document->main()->shapes, default_style, false});
+                        parse_vector({res->element, &main->shapes, default_style, false});
                 }
             }
 
@@ -94,12 +95,12 @@ protected:
                 {
                     for ( const auto& e : ElementRange(ch) )
                         if ( e.tagName() == "vector" )
-                            parse_vector({e, &document->main()->shapes, default_style, false});
+                            parse_vector({e, &main->shapes, default_style, false});
                 }
             }
         }
 
-        document->main()->name.set(
+        main->name.set(
             attr(root, "android", "name", "")
         );
     }
@@ -165,6 +166,7 @@ private:
     {
         model::FrameTime start_time = qRound(anim.attribute("startOffset", "0").toDouble() / 1000 * animate_parser.fps);
         model::FrameTime end_time = qRound(start_time + anim.attribute("duration", "0").toDouble() / 1000 * animate_parser.fps);
+        animate_parser.register_time_range(start_time, end_time);
         std::vector<AnimatedProperty*> updated_props;
 
         QString name = anim.attribute("propertyName");
@@ -403,13 +405,13 @@ private:
         stroke->miter_limit.set(parse_unit(style.get("strokeMiterLimit", "4")));
 
         auto anim = get_animations(args.element);
-        for ( const auto& kf : add_keyframes(anim.single("strokeColor")) )
+        for ( const auto& kf : anim.single("strokeColor") )
             stroke->color.set_keyframe(kf.time, kf.values.color())->set_transition(kf.transition);
 
-        for ( const auto& kf : add_keyframes(anim.single("strokeAlpha")) )
+        for ( const auto& kf : anim.single("strokeAlpha") )
             stroke->opacity.set_keyframe(kf.time, kf.values.scalar())->set_transition(kf.transition);
 
-        for ( const auto& kf : add_keyframes(anim.single("strokeWidth")) )
+        for ( const auto& kf : anim.single("strokeWidth") )
             stroke->width.set_keyframe(kf.time, kf.values.scalar())->set_transition(kf.transition);
 
         shapes->insert(std::move(stroke));
@@ -431,10 +433,10 @@ private:
             fill->fill_rule.set(model::Fill::EvenOdd);
 
         auto anim = get_animations(args.element);
-        for ( const auto& kf : add_keyframes(anim.single("fillColor")) )
+        for ( const auto& kf : anim.single("fillColor") )
             fill->color.set_keyframe(kf.time, kf.values.color())->set_transition(kf.transition);
 
-        for ( const auto& kf : add_keyframes(anim.single("fillAlpha")) )
+        for ( const auto& kf : anim.single("fillAlpha") )
             fill->opacity.set_keyframe(kf.time, kf.values.scalar())->set_transition(kf.transition);
 
         shapes->insert(std::move(fill));
@@ -450,13 +452,13 @@ private:
 
         auto anim = get_animations(args.element);
 
-        for ( const auto& kf : add_keyframes(anim.single("trimPathStart")) )
+        for ( const auto& kf : anim.single("trimPathStart") )
             trim->start.set_keyframe(kf.time, kf.values.scalar())->set_transition(kf.transition);
 
-        for ( const auto& kf : add_keyframes(anim.single("trimPathEnd")) )
+        for ( const auto& kf : anim.single("trimPathEnd") )
             trim->end.set_keyframe(kf.time, kf.values.scalar())->set_transition(kf.transition);
 
-        for ( const auto& kf : add_keyframes(anim.single("trimPathOffset")) )
+        for ( const auto& kf : anim.single("trimPathOffset") )
             trim->offset.set_keyframe(kf.time, kf.values.scalar())->set_transition(kf.transition);
 
         shapes->insert(std::move(trim));
@@ -543,7 +545,7 @@ private:
 
         auto anim = get_animations(args.element);
 
-        for ( const auto& kf : add_keyframes(anim.joined({"pivotX", "pivotY", "translateX", "translateY"})) )
+        for ( const auto& kf : anim.joined({"pivotX", "pivotY", "translateX", "translateY"}) )
         {
             anchor = QPointF(kf.values[0].scalar(), kf.values[1].scalar());
             trans->anchor_point.set_keyframe(kf.time, anchor)->set_transition(kf.transition);
@@ -551,13 +553,13 @@ private:
             trans->position.set_keyframe(kf.time, anchor + pos)->set_transition(kf.transition);
         }
 
-        for ( const auto& kf : add_keyframes(anim.joined({"scaleX", "scaleY"})) )
+        for ( const auto& kf : anim.joined({"scaleX", "scaleY"}) )
         {
             QVector2D scale(kf.values[0].scalar(), kf.values[1].scalar());
             trans->scale.set_keyframe(kf.time, scale)->set_transition(kf.transition);
         }
 
-        for ( const auto& kf : add_keyframes(anim.single("rotation")) )
+        for ( const auto& kf : anim.single("rotation") )
             trans->rotation.set_keyframe(kf.time, kf.values.scalar())->set_transition(kf.transition);
     }
 
@@ -730,9 +732,10 @@ glaxnimate::io::avd::AvdParser::AvdParser(
     model::Document* document,
     const std::function<void(const QString&)>& on_warning,
     ImportExport* io,
-    QSize forced_size
+    QSize forced_size,
+    model::FrameTime default_time
 )
-    : d(std::make_unique<Private>(resource_path, document, on_warning, io, forced_size))
+    : d(std::make_unique<Private>(resource_path, document, on_warning, io, forced_size, default_time))
 {
     d->load(device);
 }
