@@ -23,14 +23,14 @@ public:
     QString name() const override { return tr("Sprite Sheet"); }
     QStringList extensions() const override;
 
-    std::unique_ptr<app::settings::SettingsGroup> save_settings(model::Document*) const override;
+    std::unique_ptr<app::settings::SettingsGroup> save_settings(model::Composition* comp) const override;
 
     bool can_save() const override { return true; }
     bool can_open() const override { return false; }
     int priority() const override { return -2; }
 
 protected:
-    bool on_save(QIODevice & file, const QString & filename, model::Document * document, const QVariantMap & setting_values) override;
+    bool on_save(QIODevice & file, const QString & filename, model::Composition* comp, const QVariantMap & setting_values) override;
 
 private:
     static Autoreg<SpritesheetFormat> autoreg;
