@@ -1,67 +1,48 @@
+/*
+ * SPDX-FileCopyrightText: 2019-2023 Mattia Basaglia <dev@dragon.best>
+ *
+ * SPDX-License-Identifier: GPL-3.0-or-later
+ */
+
 #include "svg_parser.hpp"
-
-#include <unordered_set>
-
-#include "utils/regexp.hpp"
-#include "utils/sort_gradient.hpp"
-#include "model/shapes/group.hpp"
-#include "model/shapes/layer.hpp"
-#include "model/shapes/precomp_layer.hpp"
-#include "model/shapes/rect.hpp"
-#include "model/shapes/ellipse.hpp"
-#include "model/shapes/path.hpp"
-#include "model/shapes/polystar.hpp"
-#include "model/shapes/fill.hpp"
-#include "model/shapes/stroke.hpp"
-#include "model/shapes/image.hpp"
-#include "model/shapes/text.hpp"
-#include "model/document.hpp"
-#include "model/assets/named_color.hpp"
-
-#include "path_parser.hpp"
-#include "animate_parser.hpp"
-#include "math/math.hpp"
-#include "font_weight.hpp"
-#include "css_parser.hpp"
-#include "app/utils/string_view.hpp"
-
+#include "svg_parser_private.hpp"
 
 using namespace glaxnimate::io::svg::detail;
 
-class glaxnimate::io::svg::SvgParser::Private
+class glaxnimate::io::svg::SvgParser::Private : public SvgParserPrivate
 {
 public:
-    using ShapeCollection = std::vector<std::unique_ptr<model::ShapeElement>>;
+    Private(
+        model::Document* document,
+        const std::function<void(const QString&)>& on_warning,
+        ImportExport* io,
+        QSize forced_size,
+        model::FrameTime default_time,
+        GroupMode group_mode,
+        QDir default_asset_path
+    ) : SvgParserPrivate(document, on_warning, io, forced_size, default_time),
+        group_mode(group_mode),
+        default_asset_path(default_asset_path)
+    {}
 
-    struct ParseFuncArgs
+protected:
+    void on_parse_prepare(const QDomElement&) override
     {
-        const QDomElement& element;
-        model::ShapeListProperty* shape_parent;
-        const Style& parent_style;
-        bool in_group;
-    };
-
-    void parse()
-    {
-        size = document->size();
-        auto svg = dom.documentElement();
-        dpi = attr(svg, "inkscape", "export-xdpi", "96").toDouble();
-
-        if ( forced_size.isValid() )
-        {
-            size = forced_size;
-        }
-        else
-        {
-            size.setWidth(len_attr(svg, "width", size.width()));
-            size.setHeight(len_attr(svg, "height", size.height()));
-        }
-
         for ( const auto& p : shape_parsers )
             to_process += dom.elementsByTagName(p.first).count();
+    }
 
-        if ( io )
-            io->progress_max_changed(to_process);
+    QSizeF get_size(const QDomElement& svg) override
+    {
+        return {
+            len_attr(svg, "width", size.width()),
+            len_attr(svg, "height", size.height())
+        };
+    }
+
+    void on_parse(const QDomElement& svg) override
+    {
+        dpi = attr(svg, "inkscape", "export-xdpi", "96").toDouble();
 
         QPointF pos;
         QVector2D scale{1, 1};
@@ -109,40 +90,35 @@ public:
         }
 
         parse_css();
-        parse_defs();
+        parse_assets();
         parse_metadata();
 
-        model::Layer* parent_layer = parse_objects(svg);
+        model::Layer* parent_layer = add_layer(&main->shapes);
         parent_layer->transform.get()->position.set(-pos);
         parent_layer->transform.get()->scale.set(scale);
-
         parent_layer->name.set(
             attr(svg, "sodipodi", "docname", svg.attribute("id", parent_layer->type_name_human()))
         );
 
-        write_document_data(svg);
-    }
+        Style default_style(Style::Map{
+            {"fill", "black"},
+        });
+        parse_children({svg, &parent_layer->shapes, parse_style(svg, default_style), false});
 
-    void write_document_data(const QDomElement& svg)
-    {
-        document->main()->width.set(size.width());
-        document->main()->height.set(size.height());
-
-        if ( to_process < 1000 )
-            document->main()->recursive_rename();
-
-        document->main()->name.set(
+        main->name.set(
             attr(svg, "sodipodi", "docname", "")
         );
-
-        if ( max_time <= 0 )
-            max_time = 180;
-
-        document->main()->animation->last_frame.set(max_time);
-        for ( auto lay : layers )
-            lay->animation->last_frame.set(max_time);
     }
 
+    void parse_shape(const ParseFuncArgs& args) override
+    {
+        if ( handle_mask(args) )
+            return;
+
+        parse_shape_impl(args);
+    }
+
+private:
     void parse_css()
     {
         CssParser parser(css_blocks);
@@ -165,7 +141,25 @@ public:
         std::stable_sort(css_blocks.begin(), css_blocks.end());
     }
 
-    void parse_defs()
+    void parse_defs(const QDomNode& node)
+    {
+        if ( !node.isElement() )
+            return;
+
+        auto defs = node.toElement();
+        for ( const auto& def : ElementRange(defs) )
+        {
+            if ( def.tagName().startsWith("animate") )
+            {
+                QString link = attr(def, "xlink", "href");
+                if ( link.isEmpty() || link[0] != '#' )
+                    continue;
+                animate_parser.store_animate(link.mid(1), def);
+            }
+        }
+    }
+
+    void parse_assets()
     {
         std::vector<QDomElement> later;
 
@@ -185,6 +179,10 @@ public:
 
             std::swap(later, unprocessed);
         }
+
+
+        for ( const auto& defs : ItemCountRange(dom.elementsByTagName("defs")) )
+            parse_defs(defs);
     }
 
     void parse_gradient_node(const QDomNode& domnode, std::vector<QDomElement>& later)
@@ -272,10 +270,8 @@ public:
             brush_styles["#"+id] = col.get();
             auto anim = parse_animated(gradient.firstChildElement("stop"));
 
-            for ( const auto& kf : add_keyframes(anim.single("stop-color")) )
-                col->color.set_keyframe(kf.time,
-                    QColor::fromRgbF(kf.values.vector()[0], kf.values.vector()[1], kf.values.vector()[2], kf.values.vector()[3])
-                )->set_transition(kf.transition);
+            for ( const auto& kf : anim.single("stop-color") )
+                col->color.set_keyframe(kf.time, kf.values.color())->set_transition(kf.transition);
 
             document->assets()->colors->values.insert(std::move(col));
             return;
@@ -316,9 +312,9 @@ public:
             )));
 
             auto anim = parse_animated(element);
-            for ( const auto& kf : add_keyframes(anim.joined({"x1", "y1"})) )
+            for ( const auto& kf : anim.joined({"x1", "y1"}) )
                 gradient->start_point.set_keyframe(kf.time, {kf.values[0].vector()[0], kf.values[1].vector()[0]})->set_transition(kf.transition);
-            for ( const auto& kf : add_keyframes(anim.joined({"x2", "y2"})) )
+            for ( const auto& kf : anim.joined({"x2", "y2"}) )
                 gradient->end_point.set_keyframe(kf.time, {kf.values[0].vector()[0], kf.values[1].vector()[0]})->set_transition(kf.transition);
         }
         else if ( element.tagName() == "radialGradient" )
@@ -348,17 +344,17 @@ public:
 
 
             auto anim = parse_animated(element);
-            for ( const auto& kf : add_keyframes(anim.joined({"cx", "cy"})) )
+            for ( const auto& kf : anim.joined({"cx", "cy"}) )
                 gradient->start_point.set_keyframe(kf.time,
                     gradient_transform.map(QPointF{kf.values[0].vector()[0], kf.values[1].vector()[0]})
                 )->set_transition(kf.transition);
 
-            for ( const auto& kf : add_keyframes(anim.joined({"fx", "fy"})) )
+            for ( const auto& kf : anim.joined({"fx", "fy"}) )
                 gradient->highlight.set_keyframe(kf.time,
                     gradient_transform.map(QPointF{kf.values[0].vector()[0], kf.values[1].vector()[0]})
                 )->set_transition(kf.transition);
 
-            for ( const auto& kf : add_keyframes(anim.joined({"cx", "cy", "r"})) )
+            for ( const auto& kf : anim.joined({"cx", "cy", "r"}) )
                 gradient->end_point.set_keyframe(kf.time,
                     gradient_transform.map(QPointF{kf.values[0].vector()[0] + kf.values[2].vector()[0], kf.values[1].vector()[0]})
                 )->set_transition(kf.transition);
@@ -375,119 +371,6 @@ public:
         document->assets()->gradients->values.insert(std::move(gradient));
     }
 
-    model::Layer* parse_objects(const QDomElement& svg)
-    {
-        model::Layer* parent_layer = add_layer(&document->main()->shapes);
-        parent_layer->name.set(parent_layer->type_name_human());
-        Style default_style(Style::Map{
-            {"fill", "black"},
-        });
-        parse_children({svg, &parent_layer->shapes, parse_style(svg, default_style), false});
-
-        return parent_layer;
-    }
-
-    qreal len_attr(const QDomElement& e, const QString& name, qreal defval = 0)
-    {
-        if ( e.hasAttribute(name) )
-            return parse_unit(e.attribute(name));
-        return defval;
-    }
-
-    QString attr(const QDomElement& e, const QString& ns, const QString& name, const QString& defval = {})
-    {
-        if ( ns.isEmpty() )
-            return e.attribute(name, defval);
-        return e.attributeNS(xmlns.at(ns), name, defval);
-    }
-
-    qreal parse_unit(const QString& svg_value)
-    {
-        QRegularExpressionMatch match = unit_re.match(svg_value);
-        if ( match.hasMatch() )
-        {
-            qreal value = match.captured(1).toDouble();
-            qreal mult = unit_multiplier(match.captured(2));
-            if ( mult != 0 )
-                return value * mult;
-        }
-
-        warning(QString("Unknown length value %1").arg(svg_value));
-        return 0;
-    }
-
-    qreal unit_multiplier(const QString& unit)
-    {
-        static const constexpr qreal cmin = 2.54;
-
-        if ( unit == "px" || unit == "" )
-            return 1;
-        else if ( unit == "vw" )
-            return size.width() * 0.01;
-        else if ( unit == "vh" )
-            return size.height() * 0.01;
-        else if ( unit == "vmin" )
-            return std::min(size.width(), size.height()) * 0.01;
-        else if ( unit == "vmax" )
-            return std::max(size.width(), size.height()) * 0.01;
-        else if ( unit == "in" )
-            return dpi;
-        else if ( unit == "pc" )
-            return dpi / 6;
-        else if ( unit == "pt" )
-            return dpi / 72;
-        else if ( unit == "cm" )
-            return dpi / cmin;
-        else if ( unit == "mm" )
-            return dpi / cmin / 10;
-        else if ( unit == "Q" )
-            return dpi / cmin / 40;
-
-        return 0;
-    }
-
-    qreal unit_convert(qreal val, const QString& from, const QString& to)
-    {
-        return val * unit_multiplier(from) / unit_multiplier(to);
-    }
-
-    void warning(const QString& msg)
-    {
-        if ( on_warning )
-            on_warning(msg);
-    }
-
-    model::Layer* add_layer(model::ShapeListProperty* parent)
-    {
-        model::Layer* lay = new model::Layer(document);
-        parent->insert(std::unique_ptr<model::Layer>(lay));
-        layers.push_back(lay);
-        return lay;
-    }
-
-    QStringList split_attr(const QDomElement& e, const QString& name)
-    {
-        return e.attribute(name).split(AnimateParser::separator,
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
-        Qt::SkipEmptyParts
-#else
-        QString::SkipEmptyParts
-#endif
-        );
-    }
-
-    void parse_children(const ParseFuncArgs& args)
-    {
-        for ( const auto& domnode : ItemCountRange(args.element.childNodes()) )
-        {
-            if ( domnode.isElement() )
-            {
-                auto child = domnode.toElement();
-                parse_shape({child, args.shape_parent, args.parent_style, args.in_group});
-            }
-        }
-    }
-
     Style parse_style(const QDomElement& element, const Style& parent_style)
     {
         Style style = parent_style;
@@ -572,9 +455,9 @@ public:
 
 
         Style style = parse_style(args.element, args.parent_style);
-        auto layer = std::make_unique<model::Layer>(document);
-        apply_common_style(layer.get(), args.element, style);
-        set_name(layer.get(), args.element);
+        auto layer = add_layer(args.shape_parent);
+        apply_common_style(layer, args.element, style);
+        set_name(layer, args.element);
         layer->mask->mask.set(model::MaskSettings::Alpha);
 
         QDomElement element = args.element;
@@ -588,10 +471,12 @@ public:
         for ( const auto& attr : detail::css_atrrs )
             element.removeAttribute(attr);
 
+        Style mask_style;
+        mask_style["stroke"] = "none";
         parse_g_to_layer({
             mask_element,
             &layer->shapes,
-            style,
+            mask_style,
             false
         });
 
@@ -602,9 +487,8 @@ public:
             false
         });
 
-        parse_transform(trans_copy, layer.get(), layer->transform.get());
+        parse_transform(trans_copy, layer, layer->transform.get());
 
-        args.shape_parent->insert(std::move(layer));
         return true;
     }
 
@@ -618,55 +502,18 @@ public:
         }
     }
 
-    void parse_shape(const ParseFuncArgs& args)
-    {
-        if ( handle_mask(args) )
-            return;
-
-        parse_shape_impl(args);
-    }
-
-    template<class T>
-    T* push(ShapeCollection& sc)
-    {
-        T* t = new T(document);
-        sc.emplace_back(t);
-        return t;
-    }
-
-    void populate_ids(const QDomElement& elem)
-    {
-        if ( elem.hasAttribute("id") )
-            map_ids[elem.attribute("id")] = elem;
-
-        for ( const auto& domnode : ItemCountRange(elem.childNodes()) )
-        {
-            if ( domnode.isElement() )
-                populate_ids(domnode.toElement());
-        }
-    }
-
-    QDomElement element_by_id(const QString& id)
-    {
-        // dom.elementById() doesn't work ;_;
-        if ( map_ids.empty() )
-            populate_ids(dom.documentElement());
-        auto it = map_ids.find(id);
-        if ( it == map_ids.end() )
-            return {};
-        return it->second;
-    }
-
     void parse_transform(
         const QDomElement& element,
-        model::VisualNode* node,
+        model::Group* node,
         model::Transform* transform
     )
     {
         auto bb = node->local_bounding_rect(0);
+        bool anchor_from_inkscape = false;
         QPointF center = bb.center();
         if ( element.hasAttributeNS(detail::xmlns.at("inkscape"), "transform-center-x") )
         {
+            anchor_from_inkscape = true;
             qreal ix = element.attributeNS(detail::xmlns.at("inkscape"), "transform-center-x").toDouble();
             qreal iy = -element.attributeNS(detail::xmlns.at("inkscape"), "transform-center-y").toDouble();
             center += QPointF(ix, iy);
@@ -694,7 +541,7 @@ public:
             transform->anchor_point.set(center);
             delta_pos = center;
         }
-        else
+        else if ( anchor_from_inkscape )
         {
             auto matrix = transform->transform_matrix(transform->time());
             QPointF p1 = matrix.map(QPointF(0, 0));
@@ -707,13 +554,16 @@ public:
 
         auto anim = animate_parser.parse_animated_transform(element);
 
-        for ( const auto& kf : add_keyframes(anim.single("translate")) )
-            transform->position.set_keyframe(kf.time, QPointF{kf.values.vector()[0], kf.values.vector()[1]} + delta_pos)->set_transition(kf.transition);
+        if ( !anim.apply_motion(transform->position, delta_pos, &node->auto_orient) )
+        {
+            for ( const auto& kf : anim.single("translate") )
+                transform->position.set_keyframe(kf.time, QPointF{kf.values.vector()[0], kf.values.vector()[1]} + delta_pos)->set_transition(kf.transition);
+        }
 
-        for ( const auto& kf : add_keyframes(anim.single("scale")) )
+        for ( const auto& kf : anim.single("scale") )
             transform->scale.set_keyframe(kf.time, QVector2D(kf.values.vector()[0], kf.values.vector()[1]))->set_transition(kf.transition);
 
-        for ( const auto& kf : add_keyframes(anim.single("rotate")) )
+        for ( const auto& kf : anim.single("rotate") )
         {
             transform->rotation.set_keyframe(kf.time, kf.values.vector()[0])->set_transition(kf.transition);
             if ( kf.values.vector().size() == 3 )
@@ -725,22 +575,6 @@ public:
         }
     }
 
-    std::vector<qreal> double_args(const QString& str)
-    {
-        auto args_s = ::utils::split_ref(str, AnimateParser::separator,
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
-            Qt::SkipEmptyParts
-#else
-            QString::SkipEmptyParts
-#endif
-        );
-        std::vector<qreal> args;
-        args.reserve(args_s.size());
-        std::transform(args_s.begin(), args_s.end(), std::back_inserter(args),
-                        [](const ::utils::StringView& s){ return s.toDouble(); });
-        return args;
-    }
-
     struct ParsedTransformInfo
     {
         QTransform transform;
@@ -828,26 +662,6 @@ public:
         return info;
     }
 
-    static qreal opacity_value(const QString& v)
-    {
-        if ( v.isEmpty() )
-            return 1;
-
-        if ( v.back() == '%' )
-            return v.mid(0, v.size()-1).toDouble() / 100;
-
-        return v.toDouble();
-    }
-
-    void apply_common_style(model::VisualNode* node, const QDomElement& element, const Style& style)
-    {
-        if ( style.get("display") == "none" || style.get("visibility") == "hidden" )
-            node->visible.set(false);
-        node->locked.set(attr(element, "sodipodi", "insensitive") == "true");
-        node->set("opacity", opacity_value(style.get("opacity", "1")));
-        node->get("transform").value<model::Transform*>();
-    }
-
     void add_shapes(const ParseFuncArgs& args, ShapeCollection&& shapes)
     {
         Style style = parse_style(args.element, args.parent_style);
@@ -865,11 +679,24 @@ public:
         args.shape_parent->insert(std::move(group));
     }
 
+    void apply_common_style(model::VisualNode* node, const QDomElement& element, const Style& style)
+    {
+        if ( style.get("display") == "none" || style.get("visibility") == "hidden" )
+            node->visible.set(false);
+        node->locked.set(attr(element, "sodipodi", "insensitive") == "true");
+        node->set("opacity", percent_1(style.get("opacity", "1")));
+        node->get("transform").value<model::Transform*>();
+    }
+
     void set_name(model::DocumentNode* node, const QDomElement& element)
     {
         QString name = attr(element, "inkscape", "label");
         if ( name.isEmpty() )
-            name = element.attribute("id");
+        {
+            name = attr(element, "android", "name");
+            if ( name.isEmpty() )
+                name = element.attribute("id");
+        }
         node->name.set(name);
     }
 
@@ -914,7 +741,7 @@ public:
         model::KeyframeTransition hold;
         hold.set_hold(true);
 
-        for ( const auto& kf : add_keyframes(anim.single("display")) )
+        for ( const auto& kf : anim.single("display") )
         {
             opacity.set_keyframe(kf.time, kf.values.string() == "none" ? 0 : 1)->set_transition(hold);
         }
@@ -934,33 +761,18 @@ public:
         stroke->opacity.set(percent_1(style.get("stroke-opacity", "1")));
         stroke->width.set(parse_unit(style.get("stroke-width", "1")));
 
-        QString linecap = style.get("stroke-linecap", "butt");
-        if ( linecap == "round" )
-            stroke->cap.set(model::Stroke::RoundCap);
-        else if ( linecap == "butt" )
-            stroke->cap.set(model::Stroke::ButtCap);
-        else if ( linecap == "square" )
-            stroke->cap.set(model::Stroke::SquareCap);
-
-        QString linejoin = style.get("stroke-linejoin", "miter");
-        if ( linejoin == "round" )
-            stroke->join.set(model::Stroke::RoundJoin);
-        else if ( linejoin == "bevel" )
-            stroke->join.set(model::Stroke::BevelJoin);
-        else if ( linejoin == "miter" || linejoin == "arcs" || linejoin == "miter-clip" )
-            stroke->join.set(model::Stroke::MiterJoin);
-
+        stroke->cap.set(line_cap(style.get("stroke-linecap", "butt")));
+        stroke->join.set(line_join(style.get("stroke-linejoin", "miter")));
+        stroke->miter_limit.set(parse_unit(style.get("stroke-miterlimit", "4")));
 
         auto anim = parse_animated(args.element);
-        for ( const auto& kf : add_keyframes(anim.single("stroke")) )
-            stroke->color.set_keyframe(kf.time,
-                QColor::fromRgbF(kf.values.vector()[0], kf.values.vector()[1], kf.values.vector()[2], kf.values.vector()[3])
-            )->set_transition(kf.transition);
+        for ( const auto& kf : anim.single("stroke") )
+            stroke->color.set_keyframe(kf.time, kf.values.color())->set_transition(kf.transition);
 
-        for ( const auto& kf : add_keyframes(anim.single("stroke-opacity")) )
+        for ( const auto& kf : anim.single("stroke-opacity") )
             stroke->opacity.set_keyframe(kf.time, kf.values.vector()[0])->set_transition(kf.transition);
 
-        for ( const auto& kf : add_keyframes(anim.single("stroke-width")) )
+        for ( const auto& kf : anim.single("stroke-width") )
             stroke->width.set_keyframe(kf.time, kf.values.vector()[0])->set_transition(kf.transition);
 
         display_to_opacity(stroke.get(), anim, stroke->opacity, nullptr);
@@ -968,14 +780,6 @@ public:
         shapes->insert(std::move(stroke));
     }
 
-    // parse attributes like opacity where it's a value in [0-1] or a percentage
-    double percent_1(const QString& s)
-    {
-        if ( s.contains('%') )
-            return ::utils::mid_ref(s, 0, s.size()-1).toDouble();
-        return s.toDouble();
-    }
-
     void set_styler_style(model::Styler* styler, const QString& color_str, const QColor& current_color)
     {
         if ( !color_str.startsWith("url") )
@@ -1011,12 +815,10 @@ public:
             fill->fill_rule.set(model::Fill::EvenOdd);
 
         auto anim = parse_animated(args.element);
-        for ( const auto& kf : add_keyframes(anim.single("fill")) )
-            fill->color.set_keyframe(kf.time,
-                QColor::fromRgbF(kf.values.vector()[0], kf.values.vector()[1], kf.values.vector()[2], kf.values.vector()[3])
-            )->set_transition(kf.transition);
+        for ( const auto& kf : anim.single("fill") )
+            fill->color.set_keyframe(kf.time, kf.values.color())->set_transition(kf.transition);
 
-        for ( const auto& kf : add_keyframes(anim.single("fill-opacity")) )
+        for ( const auto& kf : anim.single("fill-opacity") )
             fill->opacity.set_keyframe(kf.time, kf.values.vector()[0])->set_transition(kf.transition);
 
         if ( fill_color == "none" )
@@ -1052,16 +854,20 @@ public:
 
 
         auto anim = parse_animated(args.element);
-        for ( const auto& kf : add_keyframes(anim.joined({"x", "y", "width", "height"})) )
+
+        /// \todo handle offset
+        anim.apply_motion(rect->position);
+
+        for ( const auto& kf : anim.joined({"x", "y", "width", "height"}) )
             rect->position.set_keyframe(kf.time, {
                 kf.values[0].vector()[0] + kf.values[2].vector()[0] / 2,
                 kf.values[1].vector()[0] + kf.values[3].vector()[0] / 2
             })->set_transition(kf.transition);
 
-        for ( const auto& kf : add_keyframes(anim.joined({"width", "height"})) )
+        for ( const auto& kf : anim.joined({"width", "height"}) )
             rect->size.set_keyframe(kf.time, {kf.values[0].vector()[0], kf.values[1].vector()[0]})->set_transition(kf.transition);
 
-        for ( const auto& kf : add_keyframes(anim.joined({"rx", "ry"})) )
+        for ( const auto& kf : anim.joined({"rx", "ry"}) )
             rect->rounded.set_keyframe(kf.time, qMax(kf.values[0].vector()[0], kf.values[1].vector()[0]))->set_transition(kf.transition);
 
         add_shapes(args, std::move(shapes));
@@ -1080,9 +886,10 @@ public:
         ellipse->size.set(QSizeF(rx * 2, ry * 2));
 
         auto anim = parse_animated(args.element);
-        for ( const auto& kf : add_keyframes(anim.joined({"cx", "cy"})) )
+        anim.apply_motion(ellipse->position);
+        for ( const auto& kf : anim.joined({"cx", "cy"}) )
             ellipse->position.set_keyframe(kf.time, {kf.values[0].vector()[0], kf.values[1].vector()[0]})->set_transition(kf.transition);
-        for ( const auto& kf : add_keyframes(anim.joined({"rx", "ry"})) )
+        for ( const auto& kf : anim.joined({"rx", "ry"}) )
             ellipse->size.set_keyframe(kf.time, {kf.values[0].vector()[0]*2, kf.values[1].vector()[0]*2})->set_transition(kf.transition);
 
         add_shapes(args, std::move(shapes));
@@ -1100,9 +907,10 @@ public:
         ellipse->size.set(QSizeF(d, d));
 
         auto anim = parse_animated(args.element);
-        for ( const auto& kf : add_keyframes(anim.joined({"cx", "cy"})) )
+        anim.apply_motion(ellipse->position);
+        for ( const auto& kf : anim.joined({"cx", "cy"}) )
             ellipse->position.set_keyframe(kf.time, {kf.values[0].vector()[0], kf.values[1].vector()[0]})->set_transition(kf.transition);
-        for ( const auto& kf : add_keyframes(anim.single({"r"})) )
+        for ( const auto& kf : anim.single({"r"}) )
             ellipse->size.set_keyframe(kf.time, {kf.values.vector()[0]*2, kf.values.vector()[0]*2})->set_transition(kf.transition);
 
         add_shapes(args, std::move(shapes));
@@ -1144,14 +952,15 @@ public:
     void parse_g_to_shape(const ParseFuncArgs& args)
     {
         Style style = parse_style(args.element, args.parent_style);
-        auto group = std::make_unique<model::Group>(document);
+        auto ugroup = std::make_unique<model::Group>(document);
+        auto group = ugroup.get();
+        args.shape_parent->insert(std::move(ugroup));
         parse_g_common(
             {args.element, &group->shapes, style, true},
-            group.get(),
+            group,
             group->transform.get(),
             style
         );
-        args.shape_parent->insert(std::move(group));
     }
 
     void parse_g_common(
@@ -1161,30 +970,38 @@ public:
         Style& style
     )
     {
+        apply_common_style(g_node, args.element, args.parent_style);
+
         auto anim = parse_animated(args.element);
+
+        for ( const auto& kf : anim.single("opacity") )
+            g_node->opacity.set_keyframe(kf.time, kf.values.vector()[0])->set_transition(kf.transition);
+
         display_to_opacity(g_node, anim, g_node->opacity, &style);
 
-        apply_common_style(g_node, args.element, args.parent_style);
         set_name(g_node, args.element);
+        // Avoid doubling opacity values
+        style.map.erase("opacity");
         parse_children(args);
         parse_transform(args.element, g_node, transform);
     }
 
-    model::Path* parse_bezier_impl(const ParseFuncArgs& args, const math::bezier::MultiBezier& bez)
+    std::vector<model::Path*> parse_bezier_impl(const ParseFuncArgs& args, const math::bezier::MultiBezier& bez)
     {
         if ( bez.beziers().empty() )
             return {};
 
         ShapeCollection shapes;
-        model::Path* shape = nullptr;
+        std::vector<model::Path*> paths;
         for ( const auto& bezier : bez.beziers() )
         {
-            shape = push<model::Path>(shapes);
+            model::Path* shape = push<model::Path>(shapes);
+            paths.push_back(shape);
             shape->shape.set(bezier);
             shape->closed.set(bezier.closed());
         }
         add_shapes(args, std::move(shapes));
-        return shape;
+        return paths;
     }
 
 
@@ -1197,15 +1014,6 @@ public:
         return path;
     }
 
-    template<class KfCollection>
-    KfCollection add_keyframes(KfCollection&& kfs)
-    {
-        if ( !kfs.empty() && kfs.back().time > max_time)
-            max_time = kfs.back().time;
-
-        return std::move(kfs);
-    }
-
     detail::AnimateParser::AnimatedProperties parse_animated(const QDomElement& element)
     {
         return animate_parser.parse_animated_properties(element);
@@ -1223,7 +1031,7 @@ public:
             len_attr(args.element, "y2", 0)
         ));
         auto path = parse_bezier_impl_single(args, bez);
-        for ( const auto& kf : add_keyframes(parse_animated(args.element).joined({"x1", "y1", "x2", "y2"})) )
+        for ( const auto& kf : parse_animated(args.element).joined({"x1", "y1", "x2", "y2"}) )
         {
             math::bezier::Bezier bez;
             bez.add_point({kf.values[0].vector()[0], kf.values[1].vector()[0]});
@@ -1260,7 +1068,7 @@ public:
         if ( !path )
             return;
 
-        for ( const auto& kf : add_keyframes(parse_animated(args.element).single("points")) )
+        for ( const auto& kf : parse_animated(args.element).single("points") )
             path->shape.set_keyframe(kf.time, build_poly(kf.values.vector(), close))->set_transition(kf.transition);
 
     }
@@ -1282,13 +1090,9 @@ public:
         QString d = args.element.attribute("d");
         math::bezier::MultiBezier bez = PathDParser(d).parse();
         /// \todo sodipodi:nodetypes
-        auto path = parse_bezier_impl(args, bez);
+        auto paths = parse_bezier_impl(args, bez);
 
-        if ( bez.size() == 1 && path )
-        {
-            for ( const auto& kf : add_keyframes(parse_animated(args.element).single("d")) )
-                path->shape.set_keyframe(kf.time, kf.values.bezier()[0])->set_transition(kf.transition);
-        }
+        path_animation(paths, parse_animated(args.element), "d" );
     }
 
     bool parse_star(const ParseFuncArgs& args)
@@ -1355,15 +1159,57 @@ public:
         args.shape_parent->insert(std::move(group));
     }
 
+    QString find_asset_file(const QString& path)
+    {
+        QFileInfo finfo(path);
+        if ( finfo.exists() )
+            return path;
+        else if ( default_asset_path.exists(path) )
+            return default_asset_path.filePath(path);
+        else if ( default_asset_path.exists(finfo.fileName()) )
+            return default_asset_path.filePath(finfo.fileName());
+
+        return {};
+    }
+
+    bool open_asset_file(model::Bitmap* image, const QString& path)
+    {
+        if ( path.isEmpty() )
+            return false;
+
+        auto file = find_asset_file(path);
+        if ( file.isEmpty() )
+            return false;
+
+        return image->from_file(file);
+    }
+
     void parseshape_image(const ParseFuncArgs& args)
     {
         auto bitmap = std::make_unique<model::Bitmap>(document);
-        if ( !bitmap->from_url(attr(args.element, "xlink", "href")) )
+
+        bool open = false;
+        QString href = attr(args.element, "xlink", "href");
+        QUrl url = href;
+
+        if ( url.isRelative() )
+            open = open_asset_file(bitmap.get(), href);
+        if ( !open )
+        {
+            if ( url.isLocalFile() )
+                open = open_asset_file(bitmap.get(), url.toLocalFile());
+            else
+                open = bitmap->from_url(url);
+        }
+
+        if ( !open )
         {
             QString path = attr(args.element, "sodipodi", "absref");
-            if ( !bitmap->from_file(path) )
-                return;
+            open = open_asset_file(bitmap.get(), path);
         }
+        if ( !open )
+            warning(QString("Could not load image %1").arg(href));
+
         auto image = std::make_unique<model::Image>(document);
         image->image.set(document->assets()->images->values.insert(std::move(bitmap)));
 
@@ -1513,7 +1359,7 @@ public:
                     last->position.set(pos + offset);
                     apply_text_style(last->font.get(), style);
 
-                    for ( const auto& kf : add_keyframes(anim.joined({"x", "y"})) )
+                    for ( const auto& kf : anim.joined({"x", "y"}) )
                     {
                         last->position.set_keyframe(
                             kf.time,
@@ -1538,13 +1384,6 @@ public:
         parse_text_element(args, {});
     }
 
-    void mark_progress()
-    {
-        processed++;
-        if ( io && processed % 10 == 0 )
-            io->progress(processed);
-    }
-
     void parse_metadata()
     {
         auto meta = dom.elementsByTagNameNS(xmlns.at("cc"), "Work");
@@ -1566,54 +1405,11 @@ public:
         }
     }
 
-    QDomElement query_element(const std::vector<QString>& path, const QDomElement& parent, std::size_t index = 0)
-    {
-        if ( index >= path.size() )
-            return parent;
-
-
-        auto head = path[index];
-        for ( const auto& domnode : ItemCountRange(parent.childNodes()) )
-        {
-            if ( domnode.isElement() )
-            {
-                auto child = domnode.toElement();
-                if ( child.tagName() == head )
-                    return query_element(path, child, index+1);
-            }
-        }
-        return {};
-    }
-
-    QString query(const std::vector<QString>& path, const QDomElement& parent, std::size_t index = 0)
-    {
-        return query_element(path, parent, index).text();
-    }
-
-    QDomDocument dom;
-
-    qreal dpi = 96;
-    QSizeF size;
-
-    model::Document* document;
-
-    AnimateParser animate_parser;
-    model::FrameTime max_time = 0;
     GroupMode group_mode;
-    std::function<void(const QString&)> on_warning;
-    std::unordered_map<QString, QDomElement> map_ids;
-    std::unordered_map<QString, model::BrushStyle*> brush_styles;
-    std::unordered_map<QString, model::GradientColors*> gradients;
-    std::vector<model::Layer*> layers;
     std::vector<CssStyleBlock> css_blocks;
-
-    int to_process = 0;
-    int processed = 0;
-    ImportExport* io = nullptr;
-    QSize forced_size;
+    QDir default_asset_path;
 
     static const std::map<QString, void (Private::*)(const ParseFuncArgs&)> shape_parsers;
-    static const QRegularExpression unit_re;
     static const QRegularExpression transform_re;
     static const QRegularExpression url_re;
 };
@@ -1631,7 +1427,7 @@ const std::map<QString, void (glaxnimate::io::svg::SvgParser::Private::*)(const
     {"image",   &glaxnimate::io::svg::SvgParser::Private::parseshape_image},
     {"text",    &glaxnimate::io::svg::SvgParser::Private::parseshape_text},
 };
-const QRegularExpression glaxnimate::io::svg::SvgParser::Private::unit_re{R"(([-+]?(?:[0-9]*\.[0-9]+|[0-9]+)([eE][-+]?[0-9]+)?)([a-z]*))"};
+const QRegularExpression glaxnimate::io::svg::detail::SvgParserPrivate::unit_re{R"(([-+]?(?:[0-9]*\.[0-9]+|[0-9]+)([eE][-+]?[0-9]+)?)([a-z]*))"};
 const QRegularExpression glaxnimate::io::svg::SvgParser::Private::transform_re{R"(([a-zA-Z]+)\s*\(([^\)]*)\))"};
 const QRegularExpression glaxnimate::io::svg::SvgParser::Private::url_re{R"(url\s*\(\s*(#[-a-zA-Z0-9_]+)\s*\)\s*)"};
 const QRegularExpression glaxnimate::io::svg::detail::AnimateParser::separator{"\\s*,\\s*|\\s+"};
@@ -1644,20 +1440,13 @@ glaxnimate::io::svg::SvgParser::SvgParser(
     model::Document* document,
     const std::function<void(const QString&)>& on_warning,
     ImportExport* io,
-    QSize forced_size
+    QSize forced_size,
+    model::FrameTime default_time,
+    QDir default_asset_path
 )
-    : d(std::make_unique<Private>())
+    : d(std::make_unique<Private>(document, on_warning, io, forced_size, default_time, group_mode, default_asset_path))
 {
-    d->document = document;
-    d->animate_parser.fps = d->document ? d->document->main()->fps.get() : 60;
-    d->group_mode = group_mode;
-    d->animate_parser.on_warning = d->on_warning = on_warning;
-    d->io = io;
-    d->forced_size = forced_size;
-
-    SvgParseError err;
-    if ( !d->dom.setContent(device, true, &err.message, &err.line, &err.column) )
-        throw err;
+    d->load(device);
 }
 
 glaxnimate::io::svg::SvgParser::~SvgParser()
@@ -1669,8 +1458,7 @@ glaxnimate::io::mime::DeserializedData glaxnimate::io::svg::SvgParser::parse_to_
 {
     glaxnimate::io::mime::DeserializedData data;
     data.initialize_data();
-    d->document = data.document.get();
-    d->parse();
+    d->parse(data.document.get());
     return data;
 }
 
