@@ -1,3 +1,9 @@
+/*
+ * SPDX-FileCopyrightText: 2019-2023 Mattia Basaglia <dev@dragon.best>
+ *
+ * SPDX-License-Identifier: GPL-3.0-or-later
+ */
+
 #pragma once
 
 #include "model/animation/animatable.hpp"
@@ -22,7 +28,7 @@ public:
 
     virtual QString type_name_human() const override { return tr("Transform"); }
 
-    QTransform transform_matrix(FrameTime f) const;
+    QTransform transform_matrix(FrameTime f, bool auto_orient = false) const;
     void set_transform_matrix(const QTransform& t);
     void copy(Transform* other);
 };
