@@ -117,8 +117,7 @@ void get_last_gps_time(gps_private_data gdata);
 double get_avg_gps_time_ms(gps_private_data gdata);
 int get_max_gps_diff_ms(gps_private_data gdata);
 int binary_search_gps(gps_private_data gdata, int64_t video_time, bool force_result = false);
-int decimals_needed(double x);
-int decimals_needed_maxone(double x);
+int decimals_needed(double x, int use_decimals = -1);
 double convert_distance_to_format(double x, const char *format);
 double convert_speed_to_format(double x, const char *format);
 const char *bearing_to_compass(double x);
