@@ -1,6 +1,6 @@
 /*
  * consumer_sdl.c -- A Simple DirectMedia Layer consumer
- * Copyright (C) 2017-2023 Meltytech, LLC
+ * Copyright (C) 2017-2024 Meltytech, LLC
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -63,7 +63,6 @@ struct consumer_sdl_s
     int width;
     int height;
     int out_channels;
-    atomic_int playing;
     SDL_Window *sdl_window;
     SDL_Renderer *sdl_renderer;
     SDL_Texture *sdl_texture;
@@ -175,7 +174,6 @@ int consumer_start(mlt_consumer parent)
         mlt_properties properties = MLT_CONSUMER_PROPERTIES(parent);
         int audio_off = mlt_properties_get_int(properties, "audio_off");
         char *output_display = mlt_properties_get(properties, "output_display");
-        char *window_id = mlt_properties_get(properties, "window_id");
         char *audio_driver = mlt_properties_get(properties, "audio_driver");
         char *video_driver = mlt_properties_get(properties, "video_driver");
         char *audio_device = mlt_properties_get(properties, "audio_device");
@@ -188,9 +186,6 @@ int consumer_start(mlt_consumer parent)
         if (output_display != NULL)
             setenv("DISPLAY", output_display, 1);
 
-        if (window_id != NULL)
-            setenv("SDL_WINDOWID", window_id, 1);
-
         if (video_driver != NULL)
             setenv("SDL_VIDEODRIVER", video_driver, 1);
 
@@ -342,9 +337,6 @@ static void sdl_fill_audio(void *udata, uint8_t *stream, int len)
         self->audio_avail = 0;
     }
 
-    // We're definitely playing now
-    self->playing = 1;
-
     pthread_cond_broadcast(&self->audio_cond);
     pthread_mutex_unlock(&self->audio_mutex);
 }
@@ -371,7 +363,6 @@ static int consumer_play_audio(consumer_sdl self, mlt_frame frame, int init_audi
     pcm += mlt_properties_get_int(properties, "audio_offset");
 
     if (mlt_properties_get_int(properties, "audio_off")) {
-        self->playing = 1;
         init_audio = 1;
         return init_audio;
     }
@@ -384,7 +375,6 @@ static int consumer_play_audio(consumer_sdl self, mlt_frame frame, int init_audi
 
         // specify audio format
         memset(&request, 0, sizeof(SDL_AudioSpec));
-        self->playing = 0;
         request.freq = frequency;
         request.format = AUDIO_S16SYS;
         request.channels = mlt_properties_get_int(properties, "channels");
@@ -472,8 +462,6 @@ static int consumer_play_audio(consumer_sdl self, mlt_frame frame, int init_audi
             pthread_cond_broadcast(&self->audio_cond);
         }
         pthread_mutex_unlock(&self->audio_mutex);
-    } else {
-        self->playing = 1;
     }
 
     return init_audio;
@@ -488,6 +476,8 @@ static int setup_sdl_video(consumer_sdl self)
     // Skip this if video is disabled.
     int video_off = mlt_properties_get_int(self->properties, "video_off");
     int preview_off = mlt_properties_get_int(self->properties, "preview_off");
+    uintptr_t window_id = mlt_properties_get_int(self->properties, "window_id");
+
     if (video_off || preview_off)
         return error;
 
@@ -524,12 +514,19 @@ static int setup_sdl_video(consumer_sdl self)
     }
 
     pthread_mutex_lock(&mlt_sdl_mutex);
-    self->sdl_window = SDL_CreateWindow("MLT",
-                                        SDL_WINDOWPOS_UNDEFINED,
-                                        SDL_WINDOWPOS_UNDEFINED,
-                                        self->window_width,
-                                        self->window_height,
-                                        sdl_flags);
+
+    if (window_id) {
+        self->sdl_window = SDL_CreateWindowFrom((void *) window_id);
+        SDL_SetWindowResizable(self->sdl_window, SDL_TRUE);
+    } else {
+        self->sdl_window = SDL_CreateWindow("MLT",
+                                            SDL_WINDOWPOS_UNDEFINED,
+                                            SDL_WINDOWPOS_UNDEFINED,
+                                            self->window_width,
+                                            self->window_height,
+                                            sdl_flags);
+    }
+
     self->sdl_renderer = SDL_CreateRenderer(self->sdl_window, -1, SDL_RENDERER_ACCELERATED);
     if (self->sdl_renderer) {
         // Get texture width and height from the profile.
@@ -575,6 +572,7 @@ static int consumer_play_video(consumer_sdl self, mlt_frame frame)
     int video_off = mlt_properties_get_int(properties, "video_off");
     int preview_off = mlt_properties_get_int(properties, "preview_off");
     int display_off = video_off | preview_off;
+    uintptr_t window_id = mlt_properties_get_int(self->properties, "window_id");
 
     if (self->running && !display_off) {
         if (!self->sdl_window) {
@@ -587,13 +585,24 @@ static int consumer_play_video(consumer_sdl self, mlt_frame frame)
         mlt_frame_get_image(frame, &image, &vfmt, &width, &height, 0);
 
         if (self->running) {
-            // Determine window's new display aspect ratio
-            int x = mlt_properties_get_int(properties, "window_width");
-            if (x && x != self->window_width)
-                self->window_width = x;
-            x = mlt_properties_get_int(properties, "window_height");
-            if (x && x != self->window_height)
-                self->window_height = x;
+            // Determine window's new display aspect ratio, and resize if it's an existing window
+            int w = mlt_properties_get_int(properties, "window_width");
+            int h = mlt_properties_get_int(properties, "window_height");
+            int width_changed = (w && w != self->window_width);
+            int height_changed = (h && h != self->window_height);
+
+            if (width_changed || height_changed) {
+                if (width_changed) {
+                    self->window_width = w;
+                }
+                if (height_changed) {
+                    self->window_height = h;
+                }
+                if (window_id) {
+                    SDL_SetWindowSize(self->sdl_window, self->window_width, self->window_height);
+                }
+            }
+
             double this_aspect = (double) self->window_width / self->window_height;
 
             // Get the display aspect ratio
@@ -708,8 +717,14 @@ static void *video_thread(void *arg)
         }
         pthread_mutex_unlock(&self->video_mutex);
 
-        if (!self->running || next == NULL)
+        if (!self->running || next == NULL) {
+            if (self->running) {
+                mlt_log_warning(
+                    MLT_CONSUMER_SERVICE(&self->parent),
+                    "video thread got a null frame even though the consumer is still running!\n");
+            }
             break;
+        }
 
         // Get the properties
         properties = MLT_FRAME_PROPERTIES(next);
@@ -804,8 +819,7 @@ static void *consumer_thread(void *arg)
             // Play audio
             init_audio = consumer_play_audio(self, frame, init_audio, &duration);
 
-            // Determine the start time now
-            if (self->playing && init_video) {
+            if (init_video) {
                 // Create the video thread
                 pthread_create(&thread, NULL, video_thread, self);
 
